@@ -125,10 +125,9 @@ const char *minibuf_read_function_name (const char *fmt, ...);
 void init_eval (void);
 
 /* file.c ----------------------------------------------------------------- */
-extern char coding_eol_lf[3];
-extern char coding_eol_crlf[3];
-extern char coding_eol_cr[3];
-extern char coding_eol_undecided[3];
+extern const char *coding_eol_lf;
+extern const char *coding_eol_crlf;
+extern const char *coding_eol_cr;
 int exist_file (const char *filename);
 astr get_home_dir (void);
 astr agetcwd (void);
@@ -222,10 +221,11 @@ Marker *copy_marker (Marker * marker);
 Marker *point_marker (void);
 
 /* minibuf.c -------------------------------------------------------------- */
-extern char *minibuf_contents;
 void init_minibuf (void);
-void minibuf_error (const char *fmt, ...);
+int minibuf_no_error (void);
+void minibuf_refresh (void);
 void minibuf_write (const char *fmt, ...);
+void minibuf_error (const char *fmt, ...);
 char *minibuf_read (const char *fmt, const char *value, ...);
 unsigned long minibuf_read_number (const char *fmt, ...);
 bool minibuf_test_in_completions (const char *ms, gl_list_t completions);
@@ -300,7 +300,6 @@ void init_variables (void);
 char *minibuf_read_variable_name (char *fmt, ...);
 void set_variable (const char *var, const char *val);
 const char *get_variable_doc (const char *var, char **defval);
-const char *get_variable_bp (Buffer * bp, const char *var);
 const char *get_variable (const char *var);
 long get_variable_number_bp (Buffer * bp, const char *var);
 long get_variable_number (const char *var);
