@@ -208,25 +208,18 @@ compact_path (astr path)
 static astr
 get_buffer_dir (void)
 {
-  astr buf;
-  const char *p, *q;
+  astr ret;
 
-  if (get_buffer_filename (cur_bp) != NULL)
-    /* If the current buffer has a filename, get the current directory
-       name from it. */
-    buf = astr_new_cstr (get_buffer_filename (cur_bp));
-  else
-    { /* Get the current directory name from the system. */
-      buf = agetcwd ();
-      if (astr_len (buf) != 0 && astr_get (buf, astr_len (buf) - 1) != '/')
-        astr_cat_char (buf, '/');
+  if (get_buffer_filename (cur_bp))
+    {
+      const char *name = dir_name (get_buffer_filename (cur_bp));
+      ret = astr_new_cstr (name);
+      free ((char *) name);
     }
+  else
+    ret = agetcwd ();
 
-  p = astr_cstr (buf);
-  q = strrchr (p, '/');
-  astr_truncate (buf, q ? q - p + 1 : 0);
-
-  return buf;
+  return ret;
 }
 
 /*
@@ -249,9 +242,9 @@ check_writable (const char *filename)
 }
 
 /* Formats of end-of-line. */
-char coding_eol_lf[3] = "\n";
-char coding_eol_crlf[3] = "\r\n";
-char coding_eol_cr[3] = "\r";
+const char *coding_eol_lf = "\n";
+const char *coding_eol_crlf = "\r\n";
+const char *coding_eol_cr = "\r";
 
 /* Maximum number of EOLs to check before deciding type. */
 #define MAX_EOL_CHECK_COUNT 3
@@ -266,7 +259,7 @@ read_file (const char *filename)
   Line *lp;
   int i, size;
   bool first_eol = true;
-  char *this_eol_type;
+  const char *this_eol_type;
   size_t eol_len = 0, total_eols = 0;
   char buf[BUFSIZ];
   FILE *fp = fopen (filename, "r");
@@ -484,12 +477,8 @@ Select buffer @i{buffer} in the current window.
           bp = find_buffer (buffer);
           if (bp == NULL)
             {
-              bp = find_buffer (buffer);
-              if (bp == NULL)
-                {
-                  bp = buffer_new ();
-                  set_buffer_name (bp, buffer);
-                }
+              bp = buffer_new ();
+              set_buffer_name (bp, buffer);
               set_buffer_needname (bp, true);
               set_buffer_nosave (bp, true);
             }
@@ -852,7 +841,7 @@ write_to_disk (Buffer * bp, const char *filename)
       if (ret == -1)
         minibuf_error ("Error writing `%s': %s", filename, strerror (errno));
       else
-        minibuf_error ("Error writing `%s': %s", filename);
+        minibuf_error ("Error writing `%s'", filename);
       return false;
     }
 
@@ -886,7 +875,7 @@ write_buffer (Buffer *bp, bool needname, bool confirm,
       ans = minibuf_read_yn ("File `%s' exists; overwrite? (y or n) ", name);
       if (ans == -1)
         FUNCALL (keyboard_quit);
-      if (ans == false)
+      else if (ans == false)
         minibuf_error ("Canceled");
       if (ans != true)
         ok = leNIL;
@@ -956,7 +945,7 @@ static int
 save_some_buffers (void)
 {
   Buffer *bp;
-  size_t i = 0;
+  bool none_to_save = true;
   bool noask = false;
 
   for (bp = head_bp; bp != NULL; bp = get_buffer_next (bp))
@@ -965,7 +954,7 @@ save_some_buffers (void)
         {
           const char *fname = get_buffer_filename_or_name (bp);
 
-          ++i;
+          none_to_save = false;
 
           if (noask)
             save_buffer (bp);
@@ -987,7 +976,6 @@ save_some_buffers (void)
                     goto endoffunc;
                   case '.':
                     save_buffer (bp);
-                    ++i;
                     return true;
                   case '!':
                     noask = true;
@@ -995,7 +983,6 @@ save_some_buffers (void)
                   case ' ':
                   case 'y':
                     save_buffer (bp);
-                    ++i;
                     /* FALLTHROUGH */
                   case 'n':
                   case KBD_RET:
@@ -1013,7 +1000,7 @@ save_some_buffers (void)
     }
 
 endoffunc:
-  if (i == 0)
+  if (none_to_save)
     minibuf_write ("(No files need saving)");
 
   return true;
