@@ -219,8 +219,8 @@ is supposed to make it easier to insert characters when necessary.
 +*/
 {
   INT_OR_UNIARG_INIT (arg);
-  set_buffer_overwrite (cur_bp, lastflag & FLAG_SET_UNIARG ? uniarg > 0 :
-                        !get_buffer_overwrite (cur_bp));
+  set_buffer_overwrite (cur_bp, noarg ? !get_buffer_overwrite (cur_bp) :
+                        uniarg > 0);
 }
 END_DEFUN
 
@@ -283,11 +283,7 @@ Just C-u as argument means to use the current column.
     }
 
   if (ok == leT)
-    {
-      le *branch = leAddDataElement (leAddDataElement (leAddDataElement (NULL, "", 0), "fill-column", 0), buf, 0);
-      F_set_variable (0, false, branch);
-      leWipe (branch);
-    }
+    set_variable ("fill-column", buf);
 
   if (arglist == NULL)
     free (buf);
@@ -356,33 +352,31 @@ Put point at beginning and mark at end of buffer.
 }
 END_DEFUN
 
-static int
+static void
 quoted_insert_octal (int c1)
 {
   int c2, c3;
-  minibuf_write ("C-q %d-", c1 - '0');
+  minibuf_write ("C-q %c-", c1);
   c2 = getkey ();
 
   if (!isdigit (c2) || c2 - '0' >= 8)
     {
       insert_char_in_insert_mode (c1 - '0');
       insert_char_in_insert_mode (c2);
-      return true;
     }
-
-  minibuf_write ("C-q %d %d-", c1 - '0', c2 - '0');
-  c3 = getkey ();
-
-  if (!isdigit (c3) || c3 - '0' >= 8)
+  else
     {
-      insert_char_in_insert_mode ((c1 - '0') * 8 + (c2 - '0'));
-      insert_char_in_insert_mode (c3);
-      return true;
+      minibuf_write ("C-q %c %c-", c1, c2);
+      c3 = getkey ();
+
+      if (!isdigit (c3) || c3 - '0' >= 8)
+        {
+          insert_char_in_insert_mode ((c1 - '0') * 8 + (c2 - '0'));
+          insert_char_in_insert_mode (c3);
+        }
+      else
+        insert_char_in_insert_mode ((c1 - '0') * 64 + (c2 - '0') * 8 + (c3 - '0'));
     }
-
-  insert_char_in_insert_mode ((c1 - '8') * 64 + (c2 - '0') * 8 + (c3 - '0'));
-
-  return true;
 }
 
 DEFUN ("quoted-insert", quoted_insert)
