@@ -1,11 +1,11 @@
 (indent-for-tab-command)
-(next-line)
+(forward-line)
 (beginning-of-line)
 (indent-for-tab-command)
-(next-line)
-(next-line)
+(forward-line)
+(forward-line)
 (beginning-of-line)
 (indent-for-tab-command)
-(next-line)
+(forward-line)
 (save-buffer)
-(save-buffers-kill-zile)
+(save-buffers-kill-emacs)
